"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.extractTemplateInfo = exports.isUrlFormat = exports.getProjectNameFromUrl = exports.parse = void 0;
var URL = require("url");
var path = require("path");
var init_error_1 = require("../error/init-error");
function parse(url) {
    return URL.parse(url);
}
exports.parse = parse;
function getProjectNameFromUrl(url) {
    var slash = url.lastIndexOf('/');
    if (slash && slash >= 0) {
        url = url.substr(slash + 1);
    }
    if (url.endsWith('.git')) {
        return url.substr(0, url.length - 4);
    }
    return url;
}
exports.getProjectNameFromUrl = getProjectNameFromUrl;
function isUrlFormat(url) {
    return url.includes(':') || url.includes('/');
}
exports.isUrlFormat = isUrlFormat;
function extractTemplateInfo(url) {
    var pathname = url.pathname || '';
    if (pathname.endsWith('.git')) {
        pathname = pathname.substr(0, pathname.length - 4);
    }
    var pathArr = pathname.split('/');
    if (pathArr.length < 3) {
        throw new init_error_1.InitError('Git repo url not correct.');
    }
    var ownerName = pathArr[1];
    var repoName = pathArr[2];
    var branch = (pathArr.length < 5) ? 'master' : pathArr[4];
    var hasSubPath = pathArr.length > 5;
    var subPath = '';
    if (hasSubPath) {
        subPath = path.join.apply(null, pathArr.slice(5));
    }
    var zipFile = '';
    if (url.hostname && url.hostname.includes('github')) {
        zipFile = url.protocol + "//" + url.host + "/" + ownerName + "/" + repoName + "/archive/" + branch + ".zip";
    }
    return {
        host: url.host,
        ownerName: ownerName,
        repoName: repoName,
        branch: branch,
        hasSubPath: hasSubPath,
        subPath: subPath,
        zipFile: zipFile
    };
}
exports.extractTemplateInfo = extractTemplateInfo;
//# sourceMappingURL=url-parser.js.map